@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.26 2006/09/26 18:12:20 bowkenken Exp $
+* $Id: call.cpp,v 1.34 2007/02/06 10:53:52 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -241,7 +241,7 @@ void	call_gui_message_draw( void )
 
 	gdk_threads_enter();
 
-	gGuiMessage.draw();
+	gGuiMessage.draw( false );
 	gGuiMessage.drawScrollBar();
 
 	gdk_flush();
@@ -317,6 +317,21 @@ void	call_gui_num_wipe( void )
 #endif // D_GTK
 }
 
+/***************************************************************
+* եåǥ쥯ȥ
+***************************************************************/
+
+void	set_str_dir_sel_graph( char *dir )
+{
+#ifdef D_WS
+	setStrDirSelGraph( dir );
+#endif // D_WS
+
+#ifdef D_GTK
+	setStrDirSelGraph( dir );
+#endif // D_GTK
+}
+
 /***************************************************************
 * եåѥΥꥻå
 ***************************************************************/
@@ -462,6 +477,130 @@ void	call_pcg_dun_scroll( long map_x, long map_y )
 #endif // D_GTK
 }
 
+/***************************************************************
+* 饯κüκɸ֤
+* chr_t *chr : 饯
+* bool flagPre : 1 κɸ
+***************************************************************/
+
+long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool flag_one_draw )
+{
+#ifdef D_WS
+	Pcg *pPcg = gPcgDun.getChrPcg( chr );
+
+	long n = gPcgDun.getChrDrawLeft( chr, pPcg, flag_one_draw );
+	n = n / gPcgDun.getTileSizeX();
+
+	return n;
+#endif // D_WS
+
+#ifdef D_GTK
+	Pcg *pPcg = gPcgDun.getChrPcg( chr );
+
+	long n = gPcgDun.getChrDrawLeft( chr, pPcg, flag_one_draw );
+	n = n / gPcgDun.getTileSizeX();
+
+	return n;
+#endif // D_GTK
+}
+
+/***************************************************************
+* 饯αüκɸ֤
+* chr_t *chr : 饯
+* bool flagPre : 1 κɸ
+***************************************************************/
+
+long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool flag_one_draw )
+{
+#ifdef D_WS
+	Pcg *pPcg = gPcgDun.getChrPcg( chr );
+
+	long n = gPcgDun.getChrDrawRight( chr, pPcg, flag_one_draw );
+	n = (n + gPcgDun.getTileSizeX() - 1) / gPcgDun.getTileSizeX();
+
+	return n;
+#endif // D_WS
+
+#ifdef D_GTK
+	Pcg *pPcg = gPcgDun.getChrPcg( chr );
+
+	long n = gPcgDun.getChrDrawRight( chr, pPcg, flag_one_draw );
+	n = (n + gPcgDun.getTileSizeX() - 1) / gPcgDun.getTileSizeX();
+
+	return n;
+#endif // D_GTK
+}
+
+/***************************************************************
+* 饯ξüκɸ֤
+* chr_t *chr : 饯
+* bool flagPre : 1 κɸ
+***************************************************************/
+
+long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool flag_one_draw )
+{
+#ifdef D_WS
+	Pcg *pPcg = gPcgDun.getChrPcg( chr );
+
+	long n = gPcgDun.getChrDrawTop( chr, pPcg, flag_one_draw );
+	n = n / gPcgDun.getTileSizeY();
+
+	return n;
+#endif // D_WS
+
+#ifdef D_GTK
+	Pcg *pPcg = gPcgDun.getChrPcg( chr );
+
+	long n = gPcgDun.getChrDrawTop( chr, pPcg, flag_one_draw );
+	n = n / gPcgDun.getTileSizeY();
+
+	return n;
+#endif // D_GTK
+}
+
+/***************************************************************
+* 饯βüκɸ֤
+* chr_t *chr : 饯
+* bool flagPre : 1 κɸ
+***************************************************************/
+
+long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool flag_one_draw )
+{
+#ifdef D_WS
+	Pcg *pPcg = gPcgDun.getChrPcg( chr );
+
+	long n = gPcgDun.getChrDrawBottom( chr, pPcg, flag_one_draw );
+	n = (n + gPcgDun.getTileSizeY() - 1) / gPcgDun.getTileSizeY();
+
+	return n;
+#endif // D_WS
+
+#ifdef D_GTK
+	Pcg *pPcg = gPcgDun.getChrPcg( chr );
+
+	long n = gPcgDun.getChrDrawBottom( chr, pPcg, flag_one_draw );
+	n = (n + gPcgDun.getTileSizeY() - 1) / gPcgDun.getTileSizeY();
+
+	return n;
+#endif // D_GTK
+}
+
+/***************************************************************
+* ɸޥåסɥɽϰ⤫Ĵ٤
+* long mapX : Xɸ
+* long mapY : Yɸ
+* return : ޥåסɥɽϰ⤫?
+***************************************************************/
+
+bool_t	call_pcg_dun_clip_win( long mapX, long mapY )
+{
+#ifdef D_GTK
+	return gPcgDun.clipWin( mapX, mapY );
+#endif // D_GTK
+
+	return true;
+}
+
 /***************************************************************
 * ơɥ
 ***************************************************************/
@@ -482,6 +621,17 @@ void	call_stat_win_redraw( void )
 #endif // D_WS
 
 #ifdef D_GTK
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gdk_threads_enter();
+
+	gGuiStat.redraw();
+
+	gdk_flush();
+	gdk_threads_leave();
 #endif // D_GTK
 }
 
