@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.h,v 1.11 2007/01/11 17:31:34 bowkenken Exp $
+* $Id: gfile.h,v 1.12 2007/02/03 00:10:00 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_H
@@ -35,8 +35,8 @@
 * ե
 ***************************************************************/
 
-#include	"amenu.h"
-#include	"spell.h"
+/* ե̾Ĺ */
+#define	FILE_NAME_MAX_LEN	127
 
 /* ϤΥȡκʸ */
 #define	TOKEN_MAX_LEN	4096
