@@ -17,10 +17,6 @@ bool_t	per_randm( long per );
 rate_t	modified_rate( rate_t rate, long n );
 bool_t	chk_ver_old( const ver_t *ver, long mjr, long mnr, long pat );
 bool_t	chk_ver_match( const ver_t *ver, long mjr, long mnr, long pat );
-long	str_len_draw( const char *s );
-long	str_len_draw_english( const char *s );
-long	str_len_draw_japanese_euc( const char *s );
-long	str_len_draw_japanese_utf_8( const char *s );
 long	str_len_std( const char *s );
 char	*str_nz_cpy( char *dst, const char *src, int len );
 char	*str_max_n_cat( char *dst, const char *src, int len );
