@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.14 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: mmenu.c,v 1.15 2007/02/02 14:09:32 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -243,6 +243,7 @@ char	*exec_menu_point_crsr( void )
 		c = chk_key( g_flg_clr_key_buf, FALSE );
 		switch( c ){
 		case CASE_CANCEL:
+		case CASE_EXEC:
 			return STR_MENU_CANCEL;
 		case ' ':
 			if( get_flg_space_select() )
@@ -899,7 +900,6 @@ bool_t	menu_mark_mnstr( pos_t pos1, pos_t pos2 )
 	str = menu_dist_mnstr();
 	if( str != NULL )
 		return FALSE;
-
 	if( g_dist_chr_kind != CHR_KIND_MNSTR )
 		return FALSE;
 
@@ -1088,6 +1088,7 @@ bool_t	menu_mark_square_pos( pos_t pos )
 	while( flg_loop ){
 		switch( get_key( g_flg_clr_key_buf ) ){
 		case CASE_CANCEL:
+		case CASE_EXEC:
 			return FALSE;
 			break;
 		case CASE_CRSR_UP:
@@ -1150,6 +1151,11 @@ char	*cb_menu_dist_init( menu_t **pp, menu_t **dflt )
 	party_t	*pty = get_party();
 	char	*dflt_path;
 
+	if( g_sel_mbr_n <= -1 )
+		return STR_MENU_ERR;
+	if( g_sel_mbr_n >= MBR_MAX_N )
+		return STR_MENU_ERR;
+
 	g_sel_dist = DIST_NEAR;
 	g_sel_act_kind = ACT_KIND_NULL;
 
@@ -2332,6 +2338,20 @@ char	*cb_menu_fight( menu_t **pp, menu_t **dflt )
 	set_menu_dflt_main( *pp );
 
 	pos1 = g_crsr;
+	c = get_chr_mjr_crsr();
+	if( c != FACE_MJR_MBR ){
+		mbr_t	*mbr;
+
+		str = exec_menu_sel_mbr( &mbr, NULL, FALSE, FALSE );
+		if( str != NULL )
+			return str;
+		if( mbr == NULL )
+			return STR_MENU_ERR;
+
+		g_sel_mbr_n = mbr->mbr_n;
+		pos1.x = mbr->x;
+		pos1.y = mbr->y;
+	}
 
 	str = exec_menu_point_crsr();
 	if( str != NULL )
