@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.181 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: mnstr.c,v 1.184 2007/02/06 17:30:27 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -151,6 +151,8 @@ void	new_mnstr( mnstr_t *mnstr )
 	mnstr->prev = NULL;
 	mnstr->next = NULL;
 #endif
+	mnstr->sort_chr_next = NULL;
+
 	mnstr->kind = CHR_KIND_MNSTR;
 	mnstr->name[0] = '0';
 	mnstr->id1 = 0;
@@ -284,6 +286,8 @@ void	new_mnstr( mnstr_t *mnstr )
 	mnstr->work.enter_door = NULL;
 	mnstr->work.dismissal_turn = 0;
 	mnstr->work.flg_used_energy_drain = FALSE;
+
+	mnstr->graph_name[0] = '\0';
 }
 
 /***************************************************************
@@ -2000,7 +2004,12 @@ void	ins_ls_mnstr( mnstr_t *ls, mnstr_t *p )
 * bool_t flg_print_lev : ٥Υåɽ뤫
 ***************************************************************/
 
-void	exp_chr_mnstr( chr_t *chr, long exp, bool_t flg_print_lev )
+void	exp_chr_mnstr(
+	chr_t *chr,
+	long exp,
+	bool_t flg_set_max,
+	bool_t flg_print_lev
+)
 {
 	long	left_exp;
 	rate_t	abl_sum;
@@ -2033,6 +2042,15 @@ void	exp_chr_mnstr( chr_t *chr, long exp, bool_t flg_print_lev )
 		e = exp * abl_rate / abl_sum;
 		chr->abl.exp[k].n += e;
 
+		if( chr->abl.exp[k].n < 0 )
+			chr->abl.exp[k].n = 0;
+		if( chr->abl.exp[k].n > EXP_MAX )
+			chr->abl.exp[k].n = EXP_MAX;
+		if( flg_set_max )
+			chr->abl.exp[k].max = chr->abl.exp[k].n;
+		if( chr->abl.exp[k].max < chr->abl.exp[k].n )
+			chr->abl.exp[k].max = chr->abl.exp[k].n;
+
 		left_exp -= e;
 		left_n++;
 		if( per_randm( left_n ) )
@@ -2040,8 +2058,15 @@ void	exp_chr_mnstr( chr_t *chr, long exp, bool_t flg_print_lev )
 	}
 
 	chr->abl.exp[left_k].n += left_exp;
+
+	if( chr->abl.exp[left_k].n < 0 )
+		chr->abl.exp[left_k].n = 0;
 	if( chr->abl.exp[left_k].n > EXP_MAX )
 		chr->abl.exp[left_k].n = EXP_MAX;
+	if( flg_set_max )
+		chr->abl.exp[left_k].max = chr->abl.exp[left_k].n;
+	if( chr->abl.exp[left_k].max < chr->abl.exp[left_k].n )
+		chr->abl.exp[left_k].max = chr->abl.exp[left_k].n;
 
 	chk_lev_up( chr, FALSE, flg_print_lev );
 }
